import { Construct } from 'constructs';
import { AwsPrincipalTagConditionKey, AwsRequestTagConditionKey } from './condition-keys';
export interface Claim {
    /**
     * Name represents the original value of the claim/attribute
     */
    readonly name: string;
    /**
     * Tag Name is name of the tag corresponding to name.
     * It can either match name or be a different value
     */
    readonly tagName: string;
}
export interface IMappedClaims {
    get claims(): Claim[];
}
export interface IClaimsContext {
    readonly mappedClaims: IMappedClaims;
    readonly knownClaims: string[];
}
export declare class MappedClaims implements IMappedClaims {
    private readonly _claims;
    static create(claim: string, ...additionalClaims: string[]): MappedClaims;
    static createMapped(claims: {
        [key: string]: string;
    }): MappedClaims;
    get claims(): Claim[];
    private constructor();
}
export declare class ClaimsUtility {
    static forContext(context: IClaimsContext): ClaimsUtility;
    readonly knownClaims: string[];
    readonly mappedClaims: IMappedClaims;
    private constructor();
    tagNameForClaim(claim: string): string;
    tagName(scope: Construct, claim: string): string;
    requestTagCondition(claim: string): AwsRequestTagConditionKey;
    principalTagCondition(claim: string): AwsPrincipalTagConditionKey;
}
