import * as ec2 from 'aws-cdk-lib/aws-ec2';
import { ConditionOperator } from '../condition-operator';
import { Constraint } from '../constraint';
import { BoolConstraint, GenericConstraint } from '../constraints';
import { BoolConditionKey, ConditionKey } from '../keys';
export declare class GlobalBoolConditionKey extends BoolConditionKey {
    static readonly MultiFactorAuthPresent: GlobalBoolConditionKey;
    static readonly PrincipalIsAWSService: GlobalBoolConditionKey;
    static readonly SecureTransport: GlobalBoolConditionKey;
    static readonly ViaAWSService: GlobalBoolConditionKey;
    private constructor();
    toBoolTrueConstraint(ifExists?: boolean): BoolConstraint;
    toBoolFalseConstraint(ifExists?: boolean): BoolConstraint;
}
export declare class AwsSourceVpcConditionKey extends ConditionKey {
    static readonly Create: AwsSourceVpcConditionKey;
    private constructor();
    toVpcConstraint(vpc: ec2.IVpc): GenericConstraint;
}
export declare class AwsRequestTagConditionKey extends ConditionKey {
    static tag(tagName: string): AwsRequestTagConditionKey;
    private constructor();
}
export declare class AwsPrincipalTagConditionKey extends ConditionKey {
    static tag(tagName: string): AwsPrincipalTagConditionKey;
    private constructor();
}
export declare class AwsResourceTagConditionKey extends ConditionKey {
    static tag(tagName: string): AwsResourceTagConditionKey;
    private constructor();
}
export declare class AwsFederatedProviderConditionKey extends ConditionKey {
    static readonly Create: AwsFederatedProviderConditionKey;
    private constructor();
    toCognitoIdentityConstraint(): Constraint;
    toConstraint(operator: ConditionOperator, value: string, ...additionalValues: string[]): GenericConstraint;
}
export declare class GlobalConditionKey extends ConditionKey {
    /**
     * Use this key to compare the services in the policy with the services that made requests on behalf of the IAM principal (user or role).
     */
    static readonly CalledVia: GlobalConditionKey;
    /**
     * Use this key to compare the services in the policy with the first service that made a request on behalf of the IAM principal (user or role).
     */
    static readonly CalledViaFirst: GlobalConditionKey;
    /**
     * Use this key to compare the services in the policy with the last service that made a request on behalf of the IAM principal (user or role).
     */
    static readonly CalledViaLast: GlobalConditionKey;
    /**
     * Use this key to compare the date and time of the request with the date and time that you specify in the policy.
     */
    static readonly CurrentTime: GlobalConditionKey;
    static readonly Ec2InstanceSourceVpc: GlobalConditionKey;
    static readonly Ec2InstanceSourcePrivateIPv4: GlobalConditionKey;
    static readonly EpochTime: GlobalConditionKey;
    static readonly FederatedProvider: AwsFederatedProviderConditionKey;
    static readonly MultiFactorAuthAge: GlobalConditionKey;
    static readonly MultiFactorAuthPresent: GlobalBoolConditionKey;
    static readonly PrincipalAccount: GlobalConditionKey;
    static readonly PrincipalArn: GlobalConditionKey;
    static readonly PrincipalIsAWSService: GlobalBoolConditionKey;
    static readonly PrincipalOrgID: GlobalConditionKey;
    static readonly PrincipalOrgPaths: GlobalConditionKey;
    static readonly PrincipalServiceName: GlobalConditionKey;
    static readonly PrincipalServiceNamesList: GlobalConditionKey;
    static readonly PrincipalType: GlobalConditionKey;
    static readonly Referer: GlobalConditionKey;
    static readonly RequestedRegion: GlobalConditionKey;
    static readonly ResourceAccount: GlobalConditionKey;
    static readonly ResourceOrgID: GlobalConditionKey;
    static readonly ResourceOrgPaths: GlobalConditionKey;
    static readonly SecureTransport: GlobalBoolConditionKey;
    static readonly SourceAccount: GlobalConditionKey;
    static readonly SourceArn: GlobalConditionKey;
    static readonly SourceIdentity: GlobalConditionKey;
    static readonly SourceIp: GlobalConditionKey;
    static readonly SourceOrgID: GlobalConditionKey;
    static readonly SourceOrgPaths: GlobalConditionKey;
    static readonly SourceVpc: AwsSourceVpcConditionKey;
    static readonly SourceVpce: GlobalConditionKey;
    static readonly TagKeys: GlobalConditionKey;
    static readonly TokenIssueTime: GlobalConditionKey;
    static readonly UserAgent: GlobalConditionKey;
    static readonly Userid: GlobalConditionKey;
    static readonly Username: GlobalConditionKey;
    static readonly ViaAWSService: GlobalBoolConditionKey;
    static readonly VpcSourceIp: GlobalConditionKey;
    /**
     * Use this key to compare the tag key-value pair that was passed in the request with the tag pair that you specify in the policy.
     * @param tagName
     */
    static requestTag(tagName: string): AwsRequestTagConditionKey;
    /**
     * Use this key to compare the tag key-value pair that you specify in the policy with the key-value pair attached to the resource.
     * @param tagName
     */
    static resourceTag(tagName: string): AwsResourceTagConditionKey;
    /**
     * Use this key to compare the tag attached to the principal making the request with the tag that you specify in the policy.
     * @param tagName
     */
    static principalTag(tagName: string): AwsPrincipalTagConditionKey;
    private constructor();
    toConstraint(operator: ConditionOperator, value: string, ...additionalValues: string[]): GenericConstraint;
}
