import { ConditionKey } from '../keys';
export declare class LambdaServiceConditionKey extends ConditionKey {
    /**
     * Filters access by the ARN of an AWS Lambda code signing config
     **/
    static readonly CodeSigningConfigArn: LambdaServiceConditionKey;
    /**
     * Filters access by the ID from a non-AWS event source configured for the AWS Lambda function
     **/
    static readonly EventSourceToken: LambdaServiceConditionKey;
    /**
     * Filters access by the ARN of an AWS Lambda function
     **/
    static readonly FunctionArn: LambdaServiceConditionKey;
    /**
     * Filters access by authorization type specified in request. Available during CreateFunctionUrlConfig, UpdateFunctionUrlConfig, DeleteFunctionUrlConfig, GetFunctionUrlConfig, ListFunctionUrlConfig, AddPermission and RemovePermission operations
     **/
    static readonly FunctionUrlAuthType: LambdaServiceConditionKey;
    /**
     * Filters access by the ARN of a version of an AWS Lambda layer
     **/
    static readonly Layer: LambdaServiceConditionKey;
    /**
     * Filters access by restricting the AWS service or account that can invoke a function
     **/
    static readonly Principal: LambdaServiceConditionKey;
    /**
     * Filters access by the ID of security groups configured for the AWS Lambda function
     **/
    static readonly SecurityGroupIds: LambdaServiceConditionKey;
    /**
     * Filters access by the ARN of the AWS Lambda function from which the request originated
     **/
    static readonly SourceFunctionArn: LambdaServiceConditionKey;
    /**
     * Filters access by the ID of subnets configured for the AWS Lambda function
     **/
    static readonly SubnetIds: LambdaServiceConditionKey;
    /**
     * Filters access by the ID of the VPC configured for the AWS Lambda function
     **/
    static readonly VpcIds: LambdaServiceConditionKey;
    private constructor();
}
