import { ConditionKey } from '../keys';
export declare class IamResourceTagConditionKey extends ConditionKey {
    static tag(tagName: string): IamResourceTagConditionKey;
    private constructor();
}
export declare class StsServiceConditionKey extends ConditionKey {
    /**
     * Filters access by the login information for Amazon Cognito
     **/
    static readonly CognitoIdentityAmr: StsServiceConditionKey;
    /**
     * Filters access by the Amazon Cognito identity pool ID
     **/
    static readonly CognitoIdentityAud: StsServiceConditionKey;
    /**
     * Filters access by the subject of the claim (the Amazon Cognito user ID)
     **/
    static readonly CognitoIdentitySub: StsServiceConditionKey;
    /**
     * Filters access by the service that is obtaining a bearer token
     **/
    static readonly AWSServiceName: StsServiceConditionKey;
    /**
     * Filters access by the duration in seconds when getting a bearer token
     **/
    static readonly DurationSeconds: StsServiceConditionKey;
    /**
     * Filters access by the unique identifier required when you assume a role in another account
     **/
    static readonly ExternalId: StsServiceConditionKey;
    /**
     * Filters access by the role session name required when you assume a role
     **/
    static readonly RoleSessionName: StsServiceConditionKey;
    /**
     * Filters access by the source identity that is passed in the request
     **/
    static readonly SourceIdentity: StsServiceConditionKey;
    /**
     * Filters access by the transitive tag keys that are passed in the request
     **/
    static readonly TransitiveTagKeys: StsServiceConditionKey;
    /**
     * Filters access by the tags that are attached to the role that is being assumed
     */
    static iamResourceTag(tagName: string): IamResourceTagConditionKey;
    private constructor();
}
