import * as iam from 'aws-cdk-lib/aws-iam';
import { Construct } from 'constructs';
import { IClaimsContext } from './claims';
import { ConditionOperator } from './condition-operator';
import { ConditionKey } from './keys';
import { PolicyType } from './policy-type';
export declare enum ConstraintPolicyMutationType {
    CONDITION = "condition"
}
export interface ConstraintPolicyMutation {
    readonly type: ConstraintPolicyMutationType;
    readonly operator: ConditionOperator;
    readonly key: ConditionKey;
    readonly value: any[];
    /** @experimental **/
    readonly order?: number;
    /** @experimental **/
    readonly strategy?: string;
    /** @experimental **/
    readonly actionsMatchService?: string;
}
export declare abstract class Constraint {
    protected constructor();
    abstract assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
    protected isNotNullCondition(key: ConditionKey): ConstraintPolicyMutation;
}
export interface ConstraintAssembleContext {
    readonly claimsContext?: IClaimsContext;
    readonly effect: iam.Effect;
    readonly policyType: PolicyType;
}
export interface ConstraintsBuilderSettings {
    readonly claimsContext?: IClaimsContext;
}
export interface IConstraintsBuilder {
    get constraints(): Constraint[];
}
export declare abstract class ConstraintsBuilder implements IConstraintsBuilder {
    private readonly _constraints;
    readonly settings: ConstraintsBuilderSettings;
    protected constructor(settings?: ConstraintsBuilderSettings);
    get constraints(): Constraint[];
    add(constraint: Constraint, ...additionalConstraints: Constraint[]): this;
}
export interface ConstraintUtilitySettings {
    readonly policyType: PolicyType;
    readonly claimsContext?: IClaimsContext;
    readonly appendConditionValues?: boolean;
}
export declare class ConstraintsUtility {
    private readonly constraints;
    static forConstraints(constraints: Constraint[]): ConstraintsUtility;
    private constructor();
    appendPolicy(scope: Construct, settings: ConstraintUtilitySettings, policyStatement: iam.PolicyStatement): void;
    appendGrant(scope: Construct, settings: ConstraintUtilitySettings, grant: iam.Grant): void;
}
