import { Construct } from 'constructs';
import { ConditionOperator } from '../condition-operator';
import { Constraint, ConstraintAssembleContext, ConstraintPolicyMutation } from '../constraint';
import { ConditionKey } from '../keys';
export declare class BoolConstraint extends Constraint {
    private readonly operator;
    private readonly key;
    private readonly value;
    static whenTrue(key: ConditionKey, ifExists?: boolean): BoolConstraint;
    static whenFalse(key: ConditionKey, ifExists?: boolean): BoolConstraint;
    private constructor();
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
export declare class DateConstraint extends Constraint {
    private readonly key;
    private readonly settings;
    static betweenDates(key: ConditionKey, from: Date, to: Date): DateConstraint;
    static greaterThan(key: ConditionKey, date: Date): DateConstraint;
    static lessThan(key: ConditionKey, date: Date): DateConstraint;
    private constructor();
    private validateDates;
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
export declare class GenericConstraint extends Constraint {
    readonly operator: ConditionOperator;
    readonly key: ConditionKey;
    readonly value: string[];
    constructor(operator: ConditionOperator, key: ConditionKey, value: string, ...additionalValues: string[]);
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
export declare class NullConstraint extends Constraint {
    private readonly key;
    private readonly isNull;
    static isNull(key: ConditionKey): NullConstraint;
    static isNotNull(key: ConditionKey): NullConstraint;
    constructor(key: ConditionKey, isNull: boolean);
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
