import { Construct } from 'constructs';
import { StringConditionOperator, StringMultiValueConditionOperator } from '../condition-operator';
import { Constraint, ConstraintAssembleContext, ConstraintPolicyMutation } from '../constraint';
export declare abstract class TagConstraint extends Constraint {
    protected constructor();
}
export declare class RequestTagConstraint extends TagConstraint {
    private readonly operator;
    readonly tagName: string;
    readonly values: string[];
    static stringEquals(tagName: string, value: string, ...values: string[]): RequestTagConstraint;
    static stringLike(tagName: string, value: string, ...values: string[]): RequestTagConstraint;
    private constructor();
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
export declare class ResourceTagConstraint extends TagConstraint {
    private readonly operator;
    readonly tagName: string;
    readonly values: string[];
    static stringEquals(tagName: string, value: string, ...values: string[]): ResourceTagConstraint;
    static create(operator: StringConditionOperator, tagName: string, value: string, ...values: string[]): ResourceTagConstraint;
    private constructor();
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
export declare class PrincipalTagConstraint extends TagConstraint {
    private readonly operator;
    readonly tagName: string;
    readonly values: string[];
    static stringEquals(tagName: string, value: string, ...values: string[]): PrincipalTagConstraint;
    private constructor();
    assemble(scope: Construct, context: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
export declare class TagKeysConstraint extends Constraint {
    readonly operator: StringMultiValueConditionOperator;
    private readonly isNotNull;
    readonly values: string[];
    static create(operator: StringMultiValueConditionOperator, isNotNull: boolean, value: string, ...values: string[]): TagKeysConstraint;
    /**
     * Limit request tags to those specified and check for null
     */
    static requireTagsEquals(value: string, ...values: string[]): TagKeysConstraint;
    private constructor();
    assemble(scope: Construct, _: ConstraintAssembleContext): ConstraintPolicyMutation[];
}
